@@ -1,2 +1,2 @@
 from lazytracker.lazytracker import LazyTracker
-from lazytracker.tracked import tracked
\ No newline at end of file
+from lazytracker.tracked import cached
